# Example Package

This package will converts coordinates from WGS84 (crs=4326) to L-Est97 (crs=3301) <br>

Install package with `pip install -i https://test.pypi.org/simple/ wgs-est-converter==1.5.7 --extra-index-url https://pypi.org/simple`